cosmpy.protos.tendermint.abci package — cosmpy documentation

# cosmpy.protos.tendermint.abci package

## Submodules

## cosmpy.protos.tendermint.abci.types_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.abci.types_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.tendermint.abci.types_pb2_grpc.ABCIApplication

  Bases: `object`

  Service Definition

  static ApplySnapshotChunk(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static BeginBlock(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static CheckTx(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Commit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static DeliverTx(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Echo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static EndBlock(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Flush(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Info(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static InitChain(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ListSnapshots(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static LoadSnapshotChunk(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static OfferSnapshot(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Query(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SetOption(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.tendermint.abci.types_pb2_grpc.ABCIApplicationServicer

  Bases: `object`

  Service Definition

  ApplySnapshotChunk(request, context)

    Missing associated documentation comment in .proto file.

  BeginBlock(request, context)

    Missing associated documentation comment in .proto file.

  CheckTx(request, context)

    Missing associated documentation comment in .proto file.

  Commit(request, context)

    Missing associated documentation comment in .proto file.

  DeliverTx(request, context)

    Missing associated documentation comment in .proto file.

  Echo(request, context)

    Missing associated documentation comment in .proto file.

  EndBlock(request, context)

    Missing associated documentation comment in .proto file.

  Flush(request, context)

    Missing associated documentation comment in .proto file.

  Info(request, context)

    Missing associated documentation comment in .proto file.

  InitChain(request, context)

    Missing associated documentation comment in .proto file.

  ListSnapshots(request, context)

    Missing associated documentation comment in .proto file.

  LoadSnapshotChunk(request, context)

    Missing associated documentation comment in .proto file.

  OfferSnapshot(request, context)

    Missing associated documentation comment in .proto file.

  Query(request, context)

    Missing associated documentation comment in .proto file.

  SetOption(request, context)

    Missing associated documentation comment in .proto file.

class cosmpy.protos.tendermint.abci.types_pb2_grpc.ABCIApplicationStub(channel)

  Bases: `object`

  Service Definition

cosmpy.protos.tendermint.abci.types_pb2_grpc.add_ABCIApplicationServicer_to_server(servicer, server)

## Module contents